@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 use strict;
 use warnings;
 use parent 'MIDI::Simple::Drummer';
-our $VERSION = '0.01';
+our $VERSION = '0.0101';
 
 sub new {
     my $self = shift;
@@ -29,7 +29,8 @@ sub _default_patterns {
     for my $i ( @$rhythm ) {
         if ( $i eq 'x' ) {
             my $pad = $self->{-pad};
-            $self->note($self->EIGHTH, $self->$pad );
+            my $note = $self->$pad || $self->snare;
+            $self->note($self->EIGHTH, $note );
         }
         else {
             $self->rest($self->EIGHTH);
@@ -96,7 +97,7 @@ MIDI::Simple::Drummer::Euclidean
 
 =head1 VERSION
 
-version 0.0803
+version 0.0804
 
 =head1 DESCRIPTION
 
@@ -132,7 +133,7 @@ Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Gene Boggs.
+This software is copyright (c) 2020 by Gene Boggs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
